@@ -46,7 +46,20 @@ class _EquivalentToList(CallbackList):
     if self._indirect is None: self._build_indirect()
     yield from self._indirect
     
+
+class _DisjointUnionList(CallbackList):
+  __slots__ = ["_bn"]
+  def __init__(self, l, obj, bn):
+    CallbackList.__init__(self, l, obj, self.callback)
+    self._bn  = bn
+    self._obj = obj
     
+  def callback(self, obj, old):
+    obj.namespace.ontology._del_list(self._bn)
+    obj.namespace.ontology._set_list(self._bn, self)
+    
+  
+
 class EntityClass(type):
   namespace = owlready
   
@@ -109,8 +122,6 @@ class EntityClass(type):
     if LOADING:
       Class = namespace.world._entities.get (storid)
     else:
-      #for base in _is_a:
-      #  if isinstance(base, ClassConstruct): base._set_ontology(namespace.ontology)
       Class = namespace.world._get_by_storid(storid)
       
     equivalent_to = obj_dict.pop("equivalent_to", None)
@@ -118,8 +129,9 @@ class EntityClass(type):
     if Class is None:
       if not LOADING:
         for base in _is_a:
-          if isinstance(base, ClassConstruct): base._set_ontology(namespace.ontology)
-          
+          if isinstance(base, ClassConstruct):
+            base._set_ontology_copy_if_needed(namespace.ontology, _is_a)
+              
       _is_a = CallbackList(_is_a, None, MetaClass._class_is_a_changed)
       obj_dict.update(
         _name          = name,
@@ -199,7 +211,9 @@ class EntityClass(type):
           x._equivalent_to._indirect = None
       
     for x in new - old:
-      if isinstance(x, ClassConstruct): x._set_ontology(Class.namespace.ontology)
+      if isinstance(x, ClassConstruct):
+        x._set_ontology_copy_if_needed(Class.namespace.ontology, Class._equivalent_to)
+          
       else: # Invalidate it
         if not x.equivalent_to._indirect is None:
           for x2 in x.equivalent_to._indirect: x2._equivalent_to._indirect = None
@@ -240,7 +254,8 @@ class EntityClass(type):
         list.insert(Class.is_a, 0, DataProperty)
         
     for base in new - old:
-      if isinstance(base, ClassConstruct): base._set_ontology(Class.namespace.ontology)
+      if isinstance(base, ClassConstruct):
+        base._set_ontology_copy_if_needed(Class.namespace.ontology, Class.is_a)
       if not LOADING: Class._add_is_a_triple(base)
       
   def disjoints(Class):
@@ -257,7 +272,7 @@ class EntityClass(type):
     for c, s, p, o in Class.namespace.world._get_obj_triples_cspo_cspo(None, None, Class._owl_disjointwith, Class.storid):
       with LOADING: a = AllDisjoint((s, p, o), Class.namespace.world.graph.context_2_user_context(c), None)
       yield a
-    
+      
   def ancestors(Class, include_self = True, include_constructs = False):
     s = set()
     Class._fill_ancestors(s, include_self, include_constructs)
@@ -427,6 +442,35 @@ class ThingClass(EntityClass):
       else:
         yield Prop
         
+  def get_disjoint_unions(Class):
+    if not "_disjoint_unions" in Class.__dict__:
+      l = []
+      for o in Class.namespace.world._get_obj_triples_sp_o(Class.storid, owl_disjointunion):
+        xs = [Class.namespace.world._get_by_storid(storid) for storid, dropit in Class.namespace.world._parse_list_as_rdf(o)]
+        du = _DisjointUnionList(xs, Class, o)
+        l.append(du)
+      Class._disjoint_unions = CallbackList(l, Class, Class.__class__._disjoint_union_changed)
+    return Class._disjoint_unions
+  def set_disjoint_unions(Class, dus): Class.disjoint_unions.reinit(dus)
+  def _disjoint_union_changed(Class, old):
+    new = Class._disjoint_unions
+    for removed in old:
+      if not removed in new:
+        Class.namespace.ontology._del_list(removed._bn)
+        Class.namespace.ontology._del_obj_triple_spo(Class.storid, owl_disjointunion, removed._bn)
+    new2 = []
+    for added in new:
+      if not added in old:
+        if not isinstance(new, _DisjointUnionList):
+          bn = Class.namespace.world.new_blank_node()
+          Class.namespace.ontology._set_list(bn, added)
+          added = _DisjointUnionList(added, Class, bn)
+        Class.namespace.ontology._add_obj_triple_spo(Class.storid, owl_disjointunion, added._bn)
+      new2.append(added)  
+    new._set(new2)
+  disjoint_unions = property(get_disjoint_unions, set_disjoint_unions)
+  
+      
   def instances(Class, world = None):
     if Class.namespace.world is owl_world:
       import owlready2
