@@ -134,7 +134,7 @@ class PropertyClass(EntityClass):
       Prop.namespace.ontology._del_obj_triple_spo(Prop.storid, rdf_domain, x.storid)
       if isinstance(x, ClassConstruct): x._set_ontology(None)
     for x in new - old:
-      if isinstance(x, ClassConstruct): x._set_ontology(Prop.namespace.ontology)
+      if isinstance(x, ClassConstruct): x._set_ontology_copy_if_needed(Prop.namespace.ontology, Prop.domain)
       Prop.namespace.ontology._add_obj_triple_spo(Prop.storid, rdf_domain, x.storid)
       
   def domains_indirect(Prop):
@@ -163,7 +163,7 @@ class PropertyClass(EntityClass):
       Prop.namespace.ontology._del_obj_triple_spo(Prop.storid, rdf_range, x2)
       if isinstance(x, ClassConstruct): x._set_ontology(None)
     for x in new - old:
-      if isinstance(x, ClassConstruct): x._set_ontology(Prop.namespace.ontology)
+      if isinstance(x, ClassConstruct): x._set_ontology_copy_if_needed(Prop.namespace.ontology, Prop.range)
       x2 = _universal_datatype_2_abbrev.get(x) or x.storid
       Prop.namespace.ontology._add_obj_triple_spo(Prop.storid, rdf_range, x2)
       
@@ -231,7 +231,7 @@ class PropertyClass(EntityClass):
       Prop.namespace.ontology._del_obj_triple_spo(Prop.storid, owl_propertychain, x.storid)
       x._set_ontology(None)
     for x in new - old:
-      x._set_ontology(Prop.namespace.ontology)
+      x._set_ontology_copy_if_needed(Prop.namespace.ontology, Prop._property_chain)
       Prop.namespace.ontology._add_obj_triple_spo(Prop.storid, owl_propertychain, x.storid)
     
     
@@ -836,6 +836,15 @@ class PropertyChain(object):
     self.ontology = ontology
     if ontology and not LOADING: self._create_triples(ontology)
     
+  def _set_ontology_copy_if_needed(self, ontology, l):
+    try:   self._set_ontology(ontology)
+    except OwlReadySharedBlankNodeError:
+      new = self.__deepcopy__()
+      new._set_ontology(ontology)
+      l.__setitem__(_is_a.index(self), new)
+      return new
+    return self
+  
   def _set_ontology(self, ontology):
     if not LOADING:
       if   self.ontology and not ontology:
